@@ -1,11 +1,15 @@
-use crate::checkers::checker_object::CheckObject;
+use crate::checkers::checker_result::CheckResult;
 
 #[cfg(not(test))]
 use text_io::read;
 
+/// The Human Checker asks humans if the expected plaintext is real plaintext
+/// We can use all the automated checkers in the world, but sometimes they get false positives
+/// Humans have the last say.
+/// TODO: Add a way to specify a list of checkers to use in the library. This checker is not library friendly!
 // compile this if we are not running tests
 #[cfg(not(test))]
-pub fn human_checker(input: &CheckObject) -> bool {
+pub fn human_checker(input: &CheckResult) -> bool {
     let output_string = format!(
         "Is the plaintext '{}' which is {}. [Y/n]? ",
         input.text, input.description
@@ -21,6 +25,6 @@ pub fn human_checker(input: &CheckObject) -> bool {
 
 // use this human_checker for tests
 #[cfg(test)]
-pub fn human_checker(_input: &CheckObject) -> bool {
+pub fn human_checker(_input: &CheckResult) -> bool {
     true
 }
